@@ -2,30 +2,31 @@ use std::borrow::Cow;
 use std::cmp::{max, min};
 use std::env;
 use std::process::{Command, Stdio};
-use std::sync::atomic::{AtomicBool, AtomicUsize, Ordering};
-use std::sync::mpsc::{channel, Receiver, Sender};
 use std::sync::Arc;
+use std::sync::atomic::{AtomicBool, AtomicUsize, Ordering};
+use std::sync::mpsc::{Receiver, Sender, channel};
 use std::thread;
 use std::thread::JoinHandle;
 
 use derive_builder::Builder;
 use nix::libc;
 use regex::Regex;
-use tuikit::prelude::{Event as TermEvent, *};
+use skim_tuikit::prelude::{Event as TermEvent, *};
 
 use crate::ansi::{ANSIParser, AnsiString};
 use crate::event::{Event, EventHandler, UpdateScreen};
 use crate::spinlock::SpinLock;
-use crate::util::{atoi, clear_canvas, depends_on_items, inject_command, InjectContext};
+use crate::util::{InjectContext, atoi, clear_canvas, depends_on_items, inject_command};
 use crate::{ItemPreview, PreviewContext, PreviewPosition, SkimItem};
 
 const TAB_STOP: usize = 8;
 const DELIMITER_STR: &str = r"[\t\n ]+";
 
 /// A wrapper around a thread-safe (Arc) to a function
+pub type PreviewCallbackFn = dyn Fn(Vec<Arc<dyn SkimItem>>) -> Vec<AnsiString<'static>> + Send + Sync + 'static;
 #[derive(Clone)]
 pub struct PreviewCallback {
-    inner: Arc<dyn Fn(Vec<Arc<dyn SkimItem>>) -> Vec<AnsiString<'static>> + Send + Sync + 'static>,
+    inner: Arc<PreviewCallbackFn>,
 }
 
 impl<F> From<F> for PreviewCallback
